@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2007 Roger While
+ * Copyright (C) 2006-2009 Roger While
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -12,7 +12,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; see the file COPYING.LIB.  If
+ * License along with this library; see the file COPYING.LIB.  If not write to
  * the Free Software Foundation, 51 Franklin Street, Fifth Floor
  * Boston, MA 02110-1301 USA
  */
@@ -24,146 +24,150 @@
 #define	COB_STATIC	static
 #else
 #define	COB_STATIC
-extern int cob_get_numdisp (const unsigned char *data, const size_t size);
-extern int cob_cmp_packed_int (const cob_field *f, const int n);
-extern int cob_get_packed_int (const cob_field *f);
-extern int cob_add_packed_int (cob_field *f, const int val);
+extern int cob_get_numdisp		(const unsigned char *, const size_t);
+extern int cob_cmp_packed_int		(const cob_field *, const int);
+extern int cob_get_packed_int		(const cob_field *);
+extern int cob_add_packed_int		(cob_field *, const int);
 
-extern int cob_cmp_u8_binary (const unsigned char *p, const int n);
-extern int cob_cmp_s8_binary (const unsigned char *p, const int n);
-extern int cob_cmp_u16_binary (const unsigned char *p, const int n);
-extern int cob_cmp_align_u16_binary (const unsigned char *p, const int n);
-extern int cob_cmp_s16_binary (const unsigned char *p, const int n);
-extern int cob_cmp_align_s16_binary (const unsigned char *p, const int n);
-extern int cob_cmp_u24_binary (const unsigned char *p, const int n);
-extern int cob_cmp_s24_binary (const unsigned char *p, const int n);
-extern int cob_cmp_u32_binary (const unsigned char *p, const int n);
-extern int cob_cmp_align_u32_binary (const unsigned char *p, const int n);
-extern int cob_cmp_s32_binary (const unsigned char *p, const int n);
-extern int cob_cmp_align_s32_binary (const unsigned char *p, const int n);
-extern int cob_cmp_u40_binary (const unsigned char *p, const int n);
-extern int cob_cmp_s40_binary (const unsigned char *p, const int n);
-extern int cob_cmp_u48_binary (const unsigned char *p, const int n);
-extern int cob_cmp_s48_binary (const unsigned char *p, const int n);
-extern int cob_cmp_u56_binary (const unsigned char *p, const int n);
-extern int cob_cmp_s56_binary (const unsigned char *p, const int n);
-extern int cob_cmp_u64_binary (const unsigned char *p, const int n);
-extern int cob_cmp_align_u64_binary (const unsigned char *p, const int n);
-extern int cob_cmp_s64_binary (const unsigned char *p, const int n);
-extern int cob_cmp_align_s64_binary (const unsigned char *p, const int n);
+extern int cob_cmp_u8_binary		(const unsigned char *, const int);
+extern int cob_cmp_s8_binary		(const unsigned char *, const int);
+extern int cob_cmp_u16_binary		(const unsigned char *, const int);
+extern int cob_cmp_s16_binary		(const unsigned char *, const int);
+extern int cob_cmp_u24_binary		(const unsigned char *, const int);
+extern int cob_cmp_s24_binary		(const unsigned char *, const int);
+extern int cob_cmp_u32_binary		(const unsigned char *, const int);
+extern int cob_cmp_s32_binary		(const unsigned char *, const int);
+extern int cob_cmp_u40_binary		(const unsigned char *, const int);
+extern int cob_cmp_s40_binary		(const unsigned char *, const int);
+extern int cob_cmp_u48_binary		(const unsigned char *, const int);
+extern int cob_cmp_s48_binary		(const unsigned char *, const int);
+extern int cob_cmp_u56_binary		(const unsigned char *, const int);
+extern int cob_cmp_s56_binary		(const unsigned char *, const int);
+extern int cob_cmp_u64_binary		(const unsigned char *, const int);
+extern int cob_cmp_s64_binary		(const unsigned char *, const int);
 
-extern void cob_add_u8_binary (unsigned char *p, const int val);
-extern void cob_add_s8_binary (unsigned char *p, const int val);
-extern void cob_add_u16_binary (unsigned char *p, const int val);
-extern void cob_add_align_u16_binary (unsigned char *p, const int val);
-extern void cob_add_s16_binary (unsigned char *p, const int val);
-extern void cob_add_align_s16_binary (unsigned char *p, const int val);
-extern void cob_add_u24_binary (unsigned char *p, const int val);
-extern void cob_add_s24_binary (unsigned char *p, const int val);
-extern void cob_add_u32_binary (unsigned char *p, const int val);
-extern void cob_add_align_u32_binary (unsigned char *p, const int val);
-extern void cob_add_s32_binary (unsigned char *p, const int val);
-extern void cob_add_align_s32_binary (unsigned char *p, const int val);
-extern void cob_add_u40_binary (unsigned char *p, const int val);
-extern void cob_add_s40_binary (unsigned char *p, const int val);
-extern void cob_add_u48_binary (unsigned char *p, const int val);
-extern void cob_add_s48_binary (unsigned char *p, const int val);
-extern void cob_add_u56_binary (unsigned char *p, const int val);
-extern void cob_add_s56_binary (unsigned char *p, const int val);
-extern void cob_add_u64_binary (unsigned char *p, const int val);
-extern void cob_add_align_u64_binary (unsigned char *p, const int val);
-extern void cob_add_s64_binary (unsigned char *p, const int val);
-extern void cob_add_align_s64_binary (unsigned char *p, const int val);
+extern int cob_cmp_align_u16_binary	(const unsigned char *, const int);
+extern int cob_cmp_align_s16_binary	(const unsigned char *, const int);
+extern int cob_cmp_align_u32_binary	(const unsigned char *, const int);
+extern int cob_cmp_align_s32_binary	(const unsigned char *, const int);
+extern int cob_cmp_align_u64_binary	(const unsigned char *, const int);
+extern int cob_cmp_align_s64_binary	(const unsigned char *, const int);
 
-extern void cob_sub_u8_binary (unsigned char *p, const int val);
-extern void cob_sub_s8_binary (unsigned char *p, const int val);
-extern void cob_sub_u16_binary (unsigned char *p, const int val);
-extern void cob_sub_align_u16_binary (unsigned char *p, const int val);
-extern void cob_sub_s16_binary (unsigned char *p, const int val);
-extern void cob_sub_align_s16_binary (unsigned char *p, const int val);
-extern void cob_sub_u24_binary (unsigned char *p, const int val);
-extern void cob_sub_s24_binary (unsigned char *p, const int val);
-extern void cob_sub_u32_binary (unsigned char *p, const int val);
-extern void cob_sub_align_u32_binary (unsigned char *p, const int val);
-extern void cob_sub_s32_binary (unsigned char *p, const int val);
-extern void cob_sub_align_s32_binary (unsigned char *p, const int val);
-extern void cob_sub_u40_binary (unsigned char *p, const int val);
-extern void cob_sub_s40_binary (unsigned char *p, const int val);
-extern void cob_sub_u48_binary (unsigned char *p, const int val);
-extern void cob_sub_s48_binary (unsigned char *p, const int val);
-extern void cob_sub_u56_binary (unsigned char *p, const int val);
-extern void cob_sub_s56_binary (unsigned char *p, const int val);
-extern void cob_sub_u64_binary (unsigned char *p, const int val);
-extern void cob_sub_align_u64_binary (unsigned char *p, const int val);
-extern void cob_sub_s64_binary (unsigned char *p, const int val);
-extern void cob_sub_align_s64_binary (unsigned char *p, const int val);
+extern void cob_add_u8_binary		(unsigned char *, const int);
+extern void cob_add_s8_binary		(unsigned char *, const int);
+extern void cob_add_u16_binary		(unsigned char *, const int);
+extern void cob_add_s16_binary		(unsigned char *, const int);
+extern void cob_add_u24_binary		(unsigned char *, const int);
+extern void cob_add_s24_binary		(unsigned char *, const int);
+extern void cob_add_u32_binary		(unsigned char *, const int);
+extern void cob_add_s32_binary		(unsigned char *, const int);
+extern void cob_add_u40_binary		(unsigned char *, const int);
+extern void cob_add_s40_binary		(unsigned char *, const int);
+extern void cob_add_u48_binary		(unsigned char *, const int);
+extern void cob_add_s48_binary		(unsigned char *, const int);
+extern void cob_add_u56_binary		(unsigned char *, const int);
+extern void cob_add_s56_binary		(unsigned char *, const int);
+extern void cob_add_u64_binary		(unsigned char *, const int);
+extern void cob_add_s64_binary		(unsigned char *, const int);
+
+extern void cob_add_align_u16_binary	(unsigned char *, const int);
+extern void cob_add_align_s16_binary	(unsigned char *, const int);
+extern void cob_add_align_u32_binary	(unsigned char *, const int);
+extern void cob_add_align_s32_binary	(unsigned char *, const int);
+extern void cob_add_align_u64_binary	(unsigned char *, const int);
+extern void cob_add_align_s64_binary	(unsigned char *, const int);
+
+extern void cob_sub_u8_binary		(unsigned char *, const int);
+extern void cob_sub_s8_binary		(unsigned char *, const int);
+extern void cob_sub_u16_binary		(unsigned char *, const int);
+extern void cob_sub_s16_binary		(unsigned char *, const int);
+extern void cob_sub_u24_binary		(unsigned char *, const int);
+extern void cob_sub_s24_binary		(unsigned char *, const int);
+extern void cob_sub_u32_binary		(unsigned char *, const int);
+extern void cob_sub_s32_binary		(unsigned char *, const int);
+extern void cob_sub_u40_binary		(unsigned char *, const int);
+extern void cob_sub_s40_binary		(unsigned char *, const int);
+extern void cob_sub_u48_binary		(unsigned char *, const int);
+extern void cob_sub_s48_binary		(unsigned char *, const int);
+extern void cob_sub_u56_binary		(unsigned char *, const int);
+extern void cob_sub_s56_binary		(unsigned char *, const int);
+extern void cob_sub_u64_binary		(unsigned char *, const int);
+extern void cob_sub_s64_binary		(unsigned char *, const int);
+
+extern void cob_sub_align_u16_binary	(unsigned char *, const int);
+extern void cob_sub_align_s16_binary	(unsigned char *, const int);
+extern void cob_sub_align_u32_binary	(unsigned char *, const int);
+extern void cob_sub_align_s32_binary	(unsigned char *, const int);
+extern void cob_sub_align_u64_binary	(unsigned char *, const int);
+extern void cob_sub_align_s64_binary	(unsigned char *, const int);
 
 #ifndef WORDS_BIGENDIAN
-extern int cob_cmpswp_u16_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_align_u16_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_s16_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_align_s16_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_u24_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_s24_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_u32_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_align_u32_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_s32_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_align_s32_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_u40_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_s40_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_u48_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_s48_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_u56_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_s56_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_u64_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_align_u64_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_s64_binary (const unsigned char *p, const int n);
-extern int cob_cmpswp_align_s64_binary (const unsigned char *p, const int n);
+extern int cob_cmpswp_u16_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_s16_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_u24_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_s24_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_u32_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_s32_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_u40_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_s40_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_u48_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_s48_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_u56_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_s56_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_u64_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_s64_binary	(const unsigned char *, const int);
 
-extern void cob_addswp_u16_binary (unsigned char *p, const int val);
-extern void cob_addswp_s16_binary (unsigned char *p, const int val);
-extern void cob_addswp_u24_binary (unsigned char *p, const int val);
-extern void cob_addswp_s24_binary (unsigned char *p, const int val);
-extern void cob_addswp_u32_binary (unsigned char *p, const int val);
-extern void cob_addswp_s32_binary (unsigned char *p, const int val);
-extern void cob_addswp_u40_binary (unsigned char *p, const int val);
-extern void cob_addswp_s40_binary (unsigned char *p, const int val);
-extern void cob_addswp_u48_binary (unsigned char *p, const int val);
-extern void cob_addswp_s48_binary (unsigned char *p, const int val);
-extern void cob_addswp_u56_binary (unsigned char *p, const int val);
-extern void cob_addswp_s56_binary (unsigned char *p, const int val);
-extern void cob_addswp_u64_binary (unsigned char *p, const int val);
-extern void cob_addswp_s64_binary (unsigned char *p, const int val);
+extern int cob_cmpswp_align_u16_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_align_s16_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_align_u32_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_align_s32_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_align_u64_binary	(const unsigned char *, const int);
+extern int cob_cmpswp_align_s64_binary	(const unsigned char *, const int);
 
-extern void cob_subswp_u16_binary (unsigned char *p, const int val);
-extern void cob_subswp_s16_binary (unsigned char *p, const int val);
-extern void cob_subswp_u24_binary (unsigned char *p, const int val);
-extern void cob_subswp_s24_binary (unsigned char *p, const int val);
-extern void cob_subswp_u32_binary (unsigned char *p, const int val);
-extern void cob_subswp_s32_binary (unsigned char *p, const int val);
-extern void cob_subswp_u40_binary (unsigned char *p, const int val);
-extern void cob_subswp_s40_binary (unsigned char *p, const int val);
-extern void cob_subswp_u48_binary (unsigned char *p, const int val);
-extern void cob_subswp_s48_binary (unsigned char *p, const int val);
-extern void cob_subswp_u56_binary (unsigned char *p, const int val);
-extern void cob_subswp_s56_binary (unsigned char *p, const int val);
-extern void cob_subswp_u64_binary (unsigned char *p, const int val);
-extern void cob_subswp_s64_binary (unsigned char *p, const int val);
+extern void cob_addswp_u16_binary	(unsigned char *, const int);
+extern void cob_addswp_s16_binary	(unsigned char *, const int);
+extern void cob_addswp_u24_binary	(unsigned char *, const int);
+extern void cob_addswp_s24_binary	(unsigned char *, const int);
+extern void cob_addswp_u32_binary	(unsigned char *, const int);
+extern void cob_addswp_s32_binary	(unsigned char *, const int);
+extern void cob_addswp_u40_binary	(unsigned char *, const int);
+extern void cob_addswp_s40_binary	(unsigned char *, const int);
+extern void cob_addswp_u48_binary	(unsigned char *, const int);
+extern void cob_addswp_s48_binary	(unsigned char *, const int);
+extern void cob_addswp_u56_binary	(unsigned char *, const int);
+extern void cob_addswp_s56_binary	(unsigned char *, const int);
+extern void cob_addswp_u64_binary	(unsigned char *, const int);
+extern void cob_addswp_s64_binary	(unsigned char *, const int);
 
-extern void cob_setswp_u16_binary (unsigned char *p, const int val);
-extern void cob_setswp_s16_binary (unsigned char *p, const int val);
-extern void cob_setswp_u24_binary (unsigned char *p, const int val);
-extern void cob_setswp_s24_binary (unsigned char *p, const int val);
-extern void cob_setswp_u32_binary (unsigned char *p, const int val);
-extern void cob_setswp_s32_binary (unsigned char *p, const int val);
-extern void cob_setswp_u40_binary (unsigned char *p, const int val);
-extern void cob_setswp_s40_binary (unsigned char *p, const int val);
-extern void cob_setswp_u48_binary (unsigned char *p, const int val);
-extern void cob_setswp_s48_binary (unsigned char *p, const int val);
-extern void cob_setswp_u56_binary (unsigned char *p, const int val);
-extern void cob_setswp_s56_binary (unsigned char *p, const int val);
-extern void cob_setswp_u64_binary (unsigned char *p, const int val);
-extern void cob_setswp_s64_binary (unsigned char *p, const int val);
+extern void cob_subswp_u16_binary	(unsigned char *, const int);
+extern void cob_subswp_s16_binary	(unsigned char *, const int);
+extern void cob_subswp_u24_binary	(unsigned char *, const int);
+extern void cob_subswp_s24_binary	(unsigned char *, const int);
+extern void cob_subswp_u32_binary	(unsigned char *, const int);
+extern void cob_subswp_s32_binary	(unsigned char *, const int);
+extern void cob_subswp_u40_binary	(unsigned char *, const int);
+extern void cob_subswp_s40_binary	(unsigned char *, const int);
+extern void cob_subswp_u48_binary	(unsigned char *, const int);
+extern void cob_subswp_s48_binary	(unsigned char *, const int);
+extern void cob_subswp_u56_binary	(unsigned char *, const int);
+extern void cob_subswp_s56_binary	(unsigned char *, const int);
+extern void cob_subswp_u64_binary	(unsigned char *, const int);
+extern void cob_subswp_s64_binary	(unsigned char *, const int);
+
+extern void cob_setswp_u16_binary	(unsigned char *, const int);
+extern void cob_setswp_s16_binary	(unsigned char *, const int);
+extern void cob_setswp_u24_binary	(unsigned char *, const int);
+extern void cob_setswp_s24_binary	(unsigned char *, const int);
+extern void cob_setswp_u32_binary	(unsigned char *, const int);
+extern void cob_setswp_s32_binary	(unsigned char *, const int);
+extern void cob_setswp_u40_binary	(unsigned char *, const int);
+extern void cob_setswp_s40_binary	(unsigned char *, const int);
+extern void cob_setswp_u48_binary	(unsigned char *, const int);
+extern void cob_setswp_s48_binary	(unsigned char *, const int);
+extern void cob_setswp_u56_binary	(unsigned char *, const int);
+extern void cob_setswp_s56_binary	(unsigned char *, const int);
+extern void cob_setswp_u64_binary	(unsigned char *, const int);
+extern void cob_setswp_s64_binary	(unsigned char *, const int);
 #endif
 #endif
 
@@ -187,7 +191,7 @@ cob_get_numdisp (const unsigned char *data, const size_t size)
 	int     retval = 0;
 	size_t	n;
 
-	for (n = 0; n < size; n++, data++) {
+	for (n = 0; n < size; ++n, ++data) {
 		retval *= 10;
 		if (*data > '9') {
 			retval += 10;
@@ -206,7 +210,7 @@ cob_cmp_packed_int (const cob_field *f, const int n)
 	int		val = 0;
 
 	p = f->data;
-	for (size = 0; size < f->size - 1; size++, p++) {
+	for (size = 0; size < f->size - 1; ++size, ++p) {
 		val *= 10;
 		val += *p >> 4;
 		val *= 10;
@@ -228,7 +232,7 @@ cob_get_packed_int (const cob_field *f)
 	int		val = 0;
 
 	p = f->data;
-	for (size = 0; size < f->size - 1; size++, p++) {
+	for (size = 0; size < f->size - 1; ++size, ++p) {
 		val *= 10;
 		val += *p >> 4;
 		val *= 10;
@@ -272,7 +276,7 @@ cob_add_packed_int (cob_field *f, const int val)
 	*p = ((inc % 10) << 4) | (*p & 0x0f);
 	p--;
 
-	for (size = 0; size < f->size - 1; size++, p--) {
+	for (size = 0; size < f->size - 1; ++size, --p) {
 		if (!carry && !n) {
 			break;
 		}
@@ -296,7 +300,7 @@ cob_cmp_align_u16_binary (const unsigned char *p, const int n)
 {
 	unsigned short	val;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 	val = *(unsigned short MISALIGNED *)p;
@@ -317,7 +321,7 @@ cob_cmp_align_u32_binary (const unsigned char *p, const int n)
 {
 	unsigned int	val;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 	val = *(unsigned int MISALIGNED *)p;
@@ -338,7 +342,7 @@ cob_cmp_align_u64_binary (const unsigned char *p, const int n)
 {
 	unsigned long long	val;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 	val = *(unsigned long long MISALIGNED *)p;
@@ -436,7 +440,7 @@ cob_cmpswp_align_u16_binary (const unsigned char *p, const int n)
 {
 	unsigned short	val;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 	val = COB_BSWAP_16 (*(unsigned short MISALIGNED *)p);
@@ -457,7 +461,7 @@ cob_cmpswp_align_u32_binary (const unsigned char *p, const int n)
 {
 	unsigned int	val;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 	val = COB_BSWAP_32 (*(unsigned int MISALIGNED *)p);
@@ -478,7 +482,7 @@ cob_cmpswp_align_u64_binary (const unsigned char *p, const int n)
 {
 	unsigned long long	val;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 	val = COB_BSWAP_64 (*(unsigned long long MISALIGNED *)p);
@@ -502,7 +506,7 @@ cob_cmpswp_align_s64_binary (const unsigned char *p, const int n)
 COB_STATIC int
 cob_cmp_u8_binary (const unsigned char *p, const int n)
 {
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 	return (*p < n) ? -1 : (*p > n);
@@ -511,22 +515,23 @@ cob_cmp_u8_binary (const unsigned char *p, const int n)
 COB_STATIC int
 cob_cmp_s8_binary (const unsigned char *p, const int n)
 {
-	return (*(signed char *)p < n) ? -1 : (*(signed char *)p > n);
+	return (*(const signed char *)p < n) ? -1 : (*(const signed char *)p > n);
 }
 
 COB_STATIC int
 cob_cmp_u16_binary (const unsigned char *p, const int n)
 {
+#ifndef ALLOW_MISALIGNED
+	unsigned char	*x;
+#endif
 	unsigned short	val;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 #ifdef ALLOW_MISALIGNED
-	val = *(unsigned short MISALIGNED *)p;
+	val = *(const unsigned short MISALIGNED *)p;
 #else
-	unsigned char	*x;
-
 	x = (unsigned char *)&val;
 	*x = *p;
 	*(x + 1) = *(p + 1);
@@ -540,7 +545,7 @@ cob_cmp_s16_binary (const unsigned char *p, const int n)
 	short	val;
 
 #ifdef ALLOW_MISALIGNED
-	val = *(short MISALIGNED *)p;
+	val = *(const short MISALIGNED *)p;
 #else
 	unsigned char	*x;
 
@@ -557,7 +562,7 @@ cob_cmp_u24_binary (const unsigned char *p, const int n)
 	unsigned char	*x;
 	unsigned int	val = 0;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 #ifdef	WORDS_BIGENDIAN
@@ -592,16 +597,17 @@ cob_cmp_s24_binary (const unsigned char *p, const int n)
 COB_STATIC int
 cob_cmp_u32_binary (const unsigned char *p, const int n)
 {
+#ifndef ALLOW_MISALIGNED
+	unsigned char	*x;
+#endif
 	unsigned int	val;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 #ifdef ALLOW_MISALIGNED
-	val = *(unsigned int MISALIGNED *)p;
+	val = *(const unsigned int MISALIGNED *)p;
 #else
-	unsigned char	*x;
-
 	x = (unsigned char *)&val;
 	*x = *p;
 	*(x + 1) = *(p + 1);
@@ -617,7 +623,7 @@ cob_cmp_s32_binary (const unsigned char *p, const int n)
 	int	val;
 
 #ifdef ALLOW_MISALIGNED
-	val = *(int MISALIGNED *)p;
+	val = *(const int MISALIGNED *)p;
 #else
 	unsigned char	*x;
 
@@ -636,7 +642,7 @@ cob_cmp_u40_binary (const unsigned char *p, const int n)
 	unsigned long long	val = 0;
 	unsigned char		*x;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 #ifdef	WORDS_BIGENDIAN
@@ -678,7 +684,7 @@ cob_cmp_u48_binary (const unsigned char *p, const int n)
 	unsigned long long	val = 0;
 	unsigned char		*x;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 #ifdef	WORDS_BIGENDIAN
@@ -722,7 +728,7 @@ cob_cmp_u56_binary (const unsigned char *p, const int n)
 	unsigned long long	val = 0;
 	unsigned char		*x;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 #ifdef	WORDS_BIGENDIAN
@@ -765,16 +771,17 @@ cob_cmp_s56_binary (const unsigned char *p, const int n)
 COB_STATIC int
 cob_cmp_u64_binary (const unsigned char *p, const int n)
 {
+#ifndef ALLOW_MISALIGNED
+	unsigned char		*x;
+#endif
 	unsigned long long	val;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 #ifdef ALLOW_MISALIGNED
-	val = *(unsigned long long MISALIGNED *)p;
+	val = *(const unsigned long long MISALIGNED *)p;
 #else
-	unsigned char		*x;
-
 	x = (unsigned char *)&val;
 	*x = *p;
 	*(x + 1) = *(p + 1);
@@ -794,7 +801,7 @@ cob_cmp_s64_binary (const unsigned char *p, const int n)
 	long long	val;
 
 #ifdef ALLOW_MISALIGNED
-	val = *(long long MISALIGNED *)p;
+	val = *(const long long MISALIGNED *)p;
 #else
 	unsigned char		*x;
 
@@ -1563,16 +1570,17 @@ cob_sub_s64_binary (unsigned char *p, const int val)
 COB_STATIC int
 cob_cmpswp_u16_binary (const unsigned char *p, const int n)
 {
+#ifndef ALLOW_MISALIGNED
+	unsigned char	*x;
+#endif
 	unsigned short	val;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 #ifdef ALLOW_MISALIGNED
 	val = COB_BSWAP_16 (*(unsigned short MISALIGNED *)p);
 #else
-	unsigned char	*x;
-
 	x = (unsigned char *)&val;
 	*x = *p;
 	*(x + 1) = *(p + 1);
@@ -1605,7 +1613,7 @@ cob_cmpswp_u24_binary (const unsigned char *p, const int n)
 	unsigned char	*x;
 	unsigned int	val = 0;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 	x = ((unsigned char *)&val) + 1;
@@ -1634,16 +1642,17 @@ cob_cmpswp_s24_binary (const unsigned char *p, const int n)
 COB_STATIC int
 cob_cmpswp_u32_binary (const unsigned char *p, const int n)
 {
+#ifndef ALLOW_MISALIGNED
+	unsigned char	*x;
+#endif
 	unsigned int	val;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 #ifdef ALLOW_MISALIGNED
-	val = COB_BSWAP_32 (*(unsigned int MISALIGNED *)p);
+	val = COB_BSWAP_32 (*(const unsigned int MISALIGNED *)p);
 #else
-	unsigned char	*x;
-
 	x = (unsigned char *)&val;
 	*x = *p;
 	*(x + 1) = *(p + 1);
@@ -1660,7 +1669,7 @@ cob_cmpswp_s32_binary (const unsigned char *p, const int n)
 	int	val;
 
 #ifdef ALLOW_MISALIGNED
-	val = COB_BSWAP_32 (*(int MISALIGNED *)p);
+	val = COB_BSWAP_32 (*(const int MISALIGNED *)p);
 #else
 	unsigned char	*x;
 
@@ -1680,7 +1689,7 @@ cob_cmpswp_u40_binary (const unsigned char *p, const int n)
 	unsigned long long	val = 0;
 	unsigned char	*x;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 	x = ((unsigned char *)&val) + 3;
@@ -1716,7 +1725,7 @@ cob_cmpswp_u48_binary (const unsigned char *p, const int n)
 	unsigned long long	val = 0;
 	unsigned char	*x;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 	x = ((unsigned char *)&val) + 2;
@@ -1754,7 +1763,7 @@ cob_cmpswp_u56_binary (const unsigned char *p, const int n)
 	unsigned long long	val = 0;
 	unsigned char	*x;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 	x = ((unsigned char *)&val) + 1;
@@ -1791,15 +1800,17 @@ cob_cmpswp_s56_binary (const unsigned char *p, const int n)
 COB_STATIC int
 cob_cmpswp_u64_binary (const unsigned char *p, const int n)
 {
+#ifndef ALLOW_MISALIGNED
+	unsigned char		*x;
+#endif
 	unsigned long long	val;
 
-	if ( n < 0 ) {
+	if (n < 0) {
 		return 1;
 	}
 #ifdef ALLOW_MISALIGNED
-	val = COB_BSWAP_64 (*(unsigned long long MISALIGNED *)p);
+	val = COB_BSWAP_64 (*(const unsigned long long MISALIGNED *)p);
 #else
-	unsigned char	*x;
 	x = (unsigned char *)&val;
 	*x = *p;
 	*(x + 1) = *(p + 1);
@@ -1820,7 +1831,7 @@ cob_cmpswp_s64_binary (const unsigned char *p, const int n)
 	long long	val;
 
 #ifdef ALLOW_MISALIGNED
-	val = COB_BSWAP_64 (*(long long MISALIGNED *)p);
+	val = COB_BSWAP_64 (*(const long long MISALIGNED *)p);
 #else
 	unsigned char	*x;
 	x = (unsigned char *)&val;
