@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2002 Keisuke Nishida
+ * Copyright (C) 2002-2009 Keisuke Nishida
+ * Copyright (C) 2007-2009 Roger While
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -13,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; see the file COPYING.LIB.  If
- * not, write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307 USA
+ * not, write to the Free Software Foundation, 51 Franklin Street, Fifth Floor
+ * Boston, MA 02110-1301 USA
  */
 
 #ifndef COB_MOVE_H
@@ -22,13 +23,8 @@
 
 #include <libcob/common.h>
 
-extern void cob_move (cob_field *src, cob_field *dst);
-extern void cob_memcpy (cob_field *dst, unsigned char *src, int size);
-extern void cob_set_int (cob_field *f, int n);
-extern int cob_get_int (cob_field *f);
-extern int cob_binary_get_int (cob_field *f);
-extern long long cob_binary_get_int64 (cob_field *f);
-extern void cob_binary_set_int (cob_field *f, int n);
-extern void cob_binary_set_int64 (cob_field *f, long long n);
+extern void		cob_move	(cob_field *, cob_field *);
+extern void		cob_set_int	(cob_field *, int);
+extern int		cob_get_int	(cob_field *);
 
-#endif /* COB_MOVE_H_ */
+#endif /* COB_MOVE_H */
